@@ -5,7 +5,7 @@ package Dist::Zilla::PluginBundle::SHANTANU;
 
 # PODNAME: Dist::Zilla::PluginBundle::SHANTANU
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 # Dependencies
 use autodie 2.00;
@@ -51,6 +51,8 @@ use Dist::Zilla::Plugin::Test::Version;
 use Dist::Zilla::Plugin::MinimumPerl;
 use Dist::Zilla::Plugin::MetaNoIndex;
 use Dist::Zilla::Plugin::MetaProvides::Package;
+use Dist::Zilla::Plugin::MetaYAML;
+use Dist::Zilla::Plugin::MetaJSON;
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 with 'Dist::Zilla::Role::PluginBundle::Config::Slicer';
@@ -337,6 +339,8 @@ sub configure {
         [ 'MetaProvides::Package' => { meta_noindex => 1 } ]
         ,    # AFTER MetaNoIndex
 
+        'MetaYAML'
+        ,    # core : Helps avoid kwalitee croaks and supports older systems
         'MetaJSON',    # core
 
         # build system
@@ -443,7 +447,7 @@ Dist::Zilla::PluginBundle::SHANTANU - Dist Zilla Plugin Bundle the way I like to
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
